@@ -8,11 +8,9 @@
 #'
 #' @return [[list]]
 norm_glm <- function(data) {
-  progress <- dplyr::progress_estimated(length(data) + 1)
   glms <- sapply(
     X = data,
     FUN = function(.data) {
-      progress$tick()$print()
       control_labels <- c("Positive", "Negative")
       .data <- .data[.data[["CodeClass"]] %in% control_labels, ]
       y <- .data[["Count"]] + 1
@@ -25,7 +23,6 @@ norm_glm <- function(data) {
       stats::glm(y ~ x, family = stats::poisson(link = "identity"))$coeff[c(1, 2)]
     }
   )
-  progress$pause(0.05)$tick()$print()
   cat("\n")
 
   list(
